@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -15,9 +15,7 @@ EnvironmentPlainTextEdit::EnvironmentPlainTextEdit(QWidget *parent)
 {
 }
 
-EnvironmentPlainTextEdit::~EnvironmentPlainTextEdit()
-{
-}
+EnvironmentPlainTextEdit::~EnvironmentPlainTextEdit() = default;
 
 void EnvironmentPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
 {
