@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -49,9 +49,9 @@ public:
 
     void restoreToDefault();
 
-    QList<int> searchColumns() const;
+    Q_REQUIRED_RESULT QList<int> searchColumns() const;
 
 private:
     void addListItems(const LoggingCategory::List &list, bool clearList);
-    QString generateToolTip(const LoggingCategory &cat);
+    Q_REQUIRED_RESULT QString generateToolTip(const LoggingCategory &cat);
 };
