@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,6 +7,7 @@
 
 #include "kdebugsettingsutil.h"
 #include "kdebugsettings_debug.h"
+#include "loadgroupmenu.h"
 #include <KLocalizedString>
 #include <QDir>
 #include <QFile>
@@ -449,3 +450,19 @@ QString KDebugSettingsUtil::qtFileName()
     const QString qtloggingFileName = envPath + QStringLiteral("/qtlogging.ini");
     return qtloggingFileName;
 }
+
+QStringList KDebugSettingsUtil::groupFileList()
+{
+    const QString groupPath = LoadGroupMenu::defaultWritableGroupPath();
+    if (groupPath.isEmpty()) {
+        return {};
+    }
+    QDir dir(groupPath);
+    const QStringList groups = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+    return groups;
+}
+
+bool KDebugSettingsUtil::hasWritableGroups()
+{
+    return !groupFileList().isEmpty();
+}
