@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,9 +7,7 @@
 
 #include "kdeloggingcategory.h"
 
-KdeLoggingCategory::KdeLoggingCategory()
-{
-}
+KdeLoggingCategory::KdeLoggingCategory() = default;
 
 bool KdeLoggingCategory::operator==(const KdeLoggingCategory &other) const
 {
